% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Dr. Jos Ernesto Rayas-Snchez                                 April 10, 2019
% Research Group on Computer-Aided Engineering of Circuits and Systems (CAECAS)
% Department of Electronics, Systems and Informatics                      ITESO
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%                   RLC Lumped Parallel Resonator (coarse model)
%
% Usage: Rc = RLC_c(Xc,psic)
%        Xc: row vector for model design parameters (length n).
%        psic: vector of independent variables where Rc should be evaluated.
%        Rc: column vector of model responses at base point Xc.
%
% Model Functions Required: RLCc_Matlab.

function Rc = RLC_c(Xc,psic)

% Pre-assigned Parameters, Xp
Xp = [];

% Simulator Parameters, Ps
f = psic;
FP = length(f); % Number of frequency points.
IF = f(1);      % Initial frequency (GHz).
FF = f(FP);     % Final frequency (GHz).
Ps = [IF FF FP];

% Calculate Responses
P = [Xp Xc Ps];
[psi,R] = RLCc_Matlab(P); 
mS11 = R(:,1);
Rc = mS11;
