% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
% Dr. Jos Ernesto Rayas-Snchez                                 April 10, 2019
% Research Group on Computer-Aided Engineering of Circuits and Systems (CAECAS)
% Department of Electronics, Systems and Informatics                      ITESO
% ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
%                   RLC Lumped Parallel Resonator (fine model)
%
% Usage: [psif,Rf] = RLC_f(Xf)                                       
%        Xf: row vector for model design parameters (length n).
%        psif: cell array of independent variables where Rf was evaluated.
%        Rf: cell array of model responses at base point Xf.
%
% Model Functions Required: RLCf_Matlab.

function [psif,Rf] = RLC_f(Xf)

% Pre-assigned Parameters, Xp
% Rp = 0.5;  % High difficulty.
% Lp = 0.13;
% Rp = 0.4;  % Medium difficulty.
% Lp = 0.09;
Rp = 0.1;  % Low difficulty.
Lp = 0.03;
Xp = [Rp Lp];

% Simulator Parameters, Ps
IF = 1;    % Initial frequency (GHz).
FF = 5;    % Final frequency (GHz).
FP = 301;  % Number of frequency samples.
Ps = [IF FF FP];

% Calculate Responses
P = [Xp Xf Ps];
[psi,R] = RLCf_Matlab(P);
mS11 = R(:,1);
psif = psi;
Rf = mS11;

